SlickGrid example 4: Model

SlickGrid
Search:

Show tasks with % at least:
And title including:

## Demonstrates:

- a filtered Model (DataView) as a data source instead of a simple array
- grid reacting to model events (onRowCountChanged, onRowsChanged)
- FAST DataView recalculation and real-time grid updating in response to data changes.
  The grid holds 50'000 rows, yet you are able to sort, filter, scroll, navigate and edit as if it had 50 rows.
- adding new rows, bidirectional sorting
- column options: cannotTriggerInsert
- events: onCellChange, onAddNewRow, onKeyDown, onSelectedRowsChanged, onSort
- NOTE: all filters are immediately applied to new/edited rows
- Handling row selection against model changes.
- Paging.
- inline filter panel

## View Source:

- View the source for this example on Github

Show tasks with title including and % at least